@@ -3,12 +3,16 @@
 
 #define EOG_CONF_DIR                         "/apps/eog"
 
+#define EOG_CONF_DESKTOP_CAN_SAVE            "/desktop/gnome/lockdown/disable_save_to_disk"
+
 #define EOG_CONF_VIEW_DIR                    "/apps/eog/view"
 #define EOG_CONF_VIEW_INTERPOLATE            "/apps/eog/view/interpolate"
 #define EOG_CONF_VIEW_TRANSPARENCY           "/apps/eog/view/transparency"
 #define EOG_CONF_VIEW_TRANS_COLOR            "/apps/eog/view/trans_color"
 
 #define EOG_CONF_WINDOW_OPEN_NEW_WINDOW      "/apps/eog/window/open_new_window"
+#define EOG_CONF_WINDOW_GEOMETRY_SINGLETON   "/apps/eog/window/geometry_singleton"
+#define EOG_CONF_WINDOW_GEOMETRY_COLLECTION  "/apps/eog/window/geometry_collection"
 
 #define EOG_CONF_FULLSCREEN_LOOP            "/apps/eog/full_screen/loop"
 #define EOG_CONF_FULLSCREEN_UPSCALE         "/apps/eog/full_screen/upscale"
@@ -16,5 +20,9 @@
 
 #define EOG_CONF_UI_TOOLBAR                  "/apps/eog/ui/toolbar"
 #define EOG_CONF_UI_STATUSBAR                "/apps/eog/ui/statusbar"
+#define EOG_CONF_UI_IMAGE_COLLECTION         "/apps/eog/ui/image_collection"
+#define EOG_CONF_UI_INFO_IMAGE               "/apps/eog/ui/info_image"
+#define EOG_CONF_UI_INFO_COLLECTION          "/apps/eog/ui/info_collection"
+
 
 #endif /* _EOG_CONFIG_KEYS_H_ */
